==> notify-1.0.2-sources.jar: de/hglabor/notify/mixins/server/MixinServerPlayerEntity.java <==
package de.hglabor.notify.mixins.server;

import PlayerDamageEvent;
import PlayerDeathEvent;
import PlayerItemDropEvent;
import PlayerSetSettingsEvent;
import de.hglabor.notify.events.server.player.*;
import me.obsilabor.alert.EventManager;
import net.minecraft.class_1282;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2803;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

@Mixin(value = class_3222.class)
public abstract class MixinServerPlayerEntity {
    @Inject(method = "tick", at = @At("TAIL"))
    public void tick(CallbackInfo ci) {
        EventManager.callEvent(new PlayerTickEvent((class_3222) (Object) this));
    }

    @Inject(method = "dropSelectedItem", at = @At("HEAD"), cancellable = true)
    public void dropSelectedItem(boolean dropAll, CallbackInfoReturnable<Boolean> cir) {
        var player = ((class_3222) (Object) this);
        var evt = new PlayerItemDropEvent(player, player.method_6047());
        EventManager.callEvent(evt);
        if (evt.isCancelled()) {
            // Sync client inventory
            player.field_7512.method_34252();
            cir.setReturnValue(false);
        }
    }

    /**
     * Called when item was already dropped; call PlayerItem<em>Dropped</em>Event
     */
    @Inject(method = "dropItem", at = @At("TAIL"), locals = LocalCapture.CAPTURE_FAILHARD)
    public void injectDropItem(class_1799 stack, boolean throwRandomly, boolean retainOwnership, CallbackInfoReturnable<class_1542> cir, class_1542 itemEntity) {
        var player = ((class_3222) (Object) this);
        EventManager.callEvent(new PlayerItemDroppedEvent(player, itemEntity));
    }

    @Inject(method = "onDeath", at = @At("HEAD"), cancellable = true)
    public void onDeath(CallbackInfo ci) {
        var player = ((class_3222) (Object) this);
        var evt = new PlayerDeathEvent(player);
        EventManager.callEvent(evt);
        if (evt.isCancelled()) {
            ci.cancel();
        }
    }

    @Inject(method = "setClientSettings", at = @At("HEAD"))
    public void setClientSettings(class_2803 settingsPacket, CallbackInfo ci) {
        var player = ((class_3222) (Object) this);
        var evt = new PlayerSetSettingsEvent(player, settingsPacket);
        EventManager.callEvent(evt);
    }

    @Inject(method = "damage", at = @At("TAIL"), cancellable = true)
    public void damage(class_1282 source, float amount, CallbackInfoReturnable<Boolean> cir) {
        var player = ((class_3222) (Object) this);
        var evt = new PlayerDamageEvent(player, source, amount);
        EventManager.callEvent(evt);
        if (evt.isCancelled()) {
            if (evt.getNewAmount() == 0f) cir.setReturnValue(false);
            else cir.setReturnValue(((class_1657) (Object) this).method_5643(source, evt.getNewAmount()));
        }
    }
}

==> notify-1.0.6-sources.jar: de/hglabor/notify/mixins/server/MixinServerPlayerEntity.java <==
package de.hglabor.notify.mixins.server;

import de.hglabor.notify.events.server.player.*;
import me.obsilabor.alert.EventManager;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1282;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2803;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

@Environment(EnvType.SERVER)
@Mixin(value = class_3222.class)
public abstract class MixinServerPlayerEntity {
    @Inject(method = "tick", at = @At("TAIL"))
    public void tick(CallbackInfo ci) {
        EventManager.callEvent(new PlayerTickEvent((class_3222) (Object) this));
    }

    @Inject(method = "dropSelectedItem", at = @At("HEAD"), cancellable = true)
    public void dropSelectedItem(boolean dropAll, CallbackInfoReturnable<Boolean> cir) {
        var player = ((class_3222) (Object) this);
        var evt = EventManager.callEvent(new PlayerItemDropEvent(player, player.method_6047()));
        if (evt.isCancelled()) {
            // Sync client inventory
            player.field_7512.method_34252();
            cir.setReturnValue(false);
        }
    }

    /**
     * Called when item was already dropped; call PlayerItem<em>Dropped</em>Event
     */
    @Inject(method = "dropItem", at = @At("TAIL"), locals = LocalCapture.CAPTURE_FAILHARD)
    public void injectDropItem(class_1799 stack, boolean throwRandomly, boolean retainOwnership, CallbackInfoReturnable<class_1542> cir, class_1542 itemEntity) {
        var player = ((class_3222) (Object) this);
        EventManager.callEvent(new PlayerItemDroppedEvent(player, itemEntity));
    }

    @Inject(method = "onDeath", at = @At("HEAD"), cancellable = true)
    public void onDeath(CallbackInfo ci) {
        var player = ((class_3222) (Object) this);
        var evt = EventManager.callEvent(new PlayerDeathEvent(player));
        if (evt.isCancelled()) {
            ci.cancel();
        }
    }

    @Inject(method = "setClientSettings", at = @At("HEAD"))
    public void setClientSettings(class_2803 settingsPacket, CallbackInfo ci) {
        var player = ((class_3222) (Object) this);
        var evt = EventManager.callEvent(new PlayerSetSettingsEvent(player, settingsPacket));
        settingsPacket = evt.getSettingsPacket();
    }

    @Inject(method = "damage", at = @At("TAIL"), cancellable = true)
    public void damage(class_1282 source, float amount, CallbackInfoReturnable<Boolean> cir) {
        var player = ((class_3222) (Object) this);
        var evt = EventManager.callEvent(new PlayerDamageEvent(player, source, amount));
        if (evt.isCancelled()) {
            if (evt.getNewAmount() == 0f) cir.setReturnValue(false);
            else cir.setReturnValue(((class_1657) (Object) this).method_5643(source, evt.getNewAmount()));
        }
    }
}
